@@ -19,6 +19,8 @@ import os
 
 CHUNK_SIZE = int(os.getenv('PYTROLL_CHUNK_SIZE', 4096))
 
+from pyresample.version import __version__  # noqa
+
 # Backwards compatibility
 from pyresample import geometry  # noqa
 from pyresample import grid  # noqa
@@ -36,21 +38,3 @@ from pyresample.plot import save_quicklook, area_def2basemap  # noqa
 
 __all__ = ['grid', 'image', 'kd_tree',
            'utils', 'plot', 'geo_filter', 'geometry', 'CHUNK_SIZE']
-
-
-def get_capabilities():
-    cap = {}
-
-    try:
-        from pykdtree.kdtree import KDTree  # noqa
-        cap['pykdtree'] = True
-    except ImportError:
-        cap['pykdtree'] = False
-
-    try:
-        import numexpr  # noqa
-        cap['numexpr'] = True
-    except ImportError:
-        cap['numexpr'] = False
-
-    return cap
