@@ -851,7 +851,7 @@ class AreaDefinition(BaseDefinition):
         self.ndim = 2
         self.pixel_size_x = (area_extent[2] - area_extent[0]) / float(x_size)
         self.pixel_size_y = (area_extent[3] - area_extent[1]) / float(y_size)
-        self.proj_dict = proj_dict
+        self.proj_dict = utils.convert_proj_floats(proj_dict.items())
         self.area_extent = tuple(area_extent)
 
         # Calculate area_extent in lon lat
@@ -920,21 +920,18 @@ class AreaDefinition(BaseDefinition):
         return crs
 
     def create_areas_def(self):
-        to_dump = OrderedDict()
-        res = OrderedDict()
-        to_dump[self.area_id] = res
 
-        res['description'] = self.name
-        res['shape'] = OrderedDict([('height', self.y_size),
-                                    ('width', self.x_size)])
-        res['area_extent'] = OrderedDict([('lower_left_xy',
-                                           list(self.area_extent[:2])),
-                                          ('upper_right_xy',
-                                           list(self.area_extent[2:])),
-                                          ('units', 'm')
-                                          ])
+        res = OrderedDict(description=self.name,
+                          projection=OrderedDict(self.proj_dict),
+                          shape=OrderedDict([('height', self.y_size), ('width', self.x_size)]))
+        units = res['projection'].pop('units', None)
+        extent = OrderedDict([('lower_left_xy', list(self.area_extent[:2])),
+                              ('upper_right_xy', list(self.area_extent[2:]))])
+        if units is not None:
+            extent['units'] = units
+        res['area_extent'] = extent
 
-        return ordered_dump(to_dump)
+        return ordered_dump(OrderedDict([(self.area_id, res)]))
 
     def create_areas_def_legacy(self):
         proj_dict = self.proj_dict
@@ -1452,13 +1449,17 @@ def get_geostationary_bounding_box(geos_area, nb_points=50):
 
 def combine_area_extents_vertical(area1, area2):
     """Combine the area extents of areas 1 and 2."""
-    if (area1.area_extent[0] == area2.area_extent[0] and
-            area1.area_extent[2] == area2.area_extent[2]):
+    if (area1.area_extent[0] == area2.area_extent[0]
+            and area1.area_extent[2] == area2.area_extent[2]):
         current_extent = list(area1.area_extent)
         if np.isclose(area1.area_extent[1], area2.area_extent[3]):
             current_extent[1] = area2.area_extent[1]
         elif np.isclose(area1.area_extent[3], area2.area_extent[1]):
             current_extent[3] = area2.area_extent[3]
+        else:
+            raise IncompatibleAreas(
+                "Can't concatenate non-contiguous area definitions: "
+                "{0} and {1}".format(area1, area2))
     else:
         raise IncompatibleAreas(
             "Can't concatenate area definitions with "
