@@ -23,7 +23,6 @@
 """The test base.
 """
 
-
 from pyresample.test import (
     test_geometry,
     test_grid,
@@ -31,6 +30,7 @@ from pyresample.test import (
     test_kd_tree,
     test_plot,
     test_spherical_geometry,
+    test_spherical,
     test_swath,
     test_utils,
     test_ewa_ll2cr,
@@ -53,6 +53,7 @@ def suite():
     mysuite.addTests(test_kd_tree.suite())
     mysuite.addTests(test_plot.suite())
     mysuite.addTests(test_spherical_geometry.suite())
+    mysuite.addTests(test_spherical.suite())
     mysuite.addTests(test_swath.suite())
     mysuite.addTests(test_utils.suite())
     mysuite.addTests(test_ewa_ll2cr.suite())
