@@ -1,3 +1,21 @@
+#!/usr/bin/env python
+# encoding: utf8
+#
+# Copyright (C) 2014-2018 PyTroll developers
+#
+# This program is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 3 of the License, or (at your option) any
+# later version.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 import unittest
 import os
 
@@ -9,10 +27,10 @@ try:
 except ImportError:
     pass  # Postpone fail to individual tests
 
-
-def tmp(f):
-    f.tmp = True
-    return f
+try:
+    from mpl_toolkits.basemap import Basemap
+except ImportError:
+    Basemap = None
 
 
 class Test(unittest.TestCase):
@@ -28,9 +46,9 @@ class Test(unittest.TestCase):
     fvalue = -10000000000.0
     valid_fov = (lons != fvalue) * (lats != fvalue) * (tb37v != fvalue)
     lons = lons[valid_fov]
-    lats = lats[valid_fov] 
+    lats = lats[valid_fov]
     tb37v = tb37v[valid_fov]
- 
+
     def test_ellps2axis(self):
         from pyresample import plot
         a, b = plot.ellps2axis('WGS84')
@@ -39,6 +57,7 @@ class Test(unittest.TestCase):
         self.assertAlmostEqual(b, 6356752.3142451793,
                                msg='Failed to get semi-minor axis of ellipsis')
 
+    @unittest.skipIf(Basemap is None, "basemap is not available")
     def test_area_def2basemap(self):
         from pyresample import plot, utils
         area_def = utils.parse_area_file(os.path.join(os.path.dirname(__file__),
