@@ -28,7 +28,7 @@ import numpy as np
 import six
 import yaml
 from configobj import ConfigObj
-from collections import Mapping
+from collections import Mapping, OrderedDict
 
 
 class AreaNotFound(KeyError):
@@ -149,6 +149,10 @@ def _parse_yaml_area_file(area_file_name, *regions):
                            params['area_extent']['upper_right_xy'])
         except KeyError:
             area_extent = None
+        try:
+            projection['units'] = params['area_extent']['units']
+        except KeyError:
+            pass
         try:
             rotation = params['rotation']
         except KeyError:
@@ -202,7 +206,7 @@ def _parse_legacy_area_file(area_file_name, *regions):
     in_area = False
     for line in area_file:
         if not in_area:
-            if 'REGION' in line:
+            if 'REGION' in line and not line.strip().startswith('#'):
                 area_id = line.replace('REGION:', ''). \
                     replace('{', '').strip()
                 if area_id in area_list or select_all_areas:
@@ -210,11 +214,14 @@ def _parse_legacy_area_file(area_file_name, *regions):
                     area_content = ''
         elif '};' in line:
             in_area = False
-            if select_all_areas:
-                area_defs.append(_create_area(area_id, area_content))
-            else:
-                area_defs[area_list.index(area_id)] = _create_area(area_id,
-                                                                   area_content)
+            try:
+                if select_all_areas:
+                    area_defs.append(_create_area(area_id, area_content))
+                else:
+                    area_defs[area_list.index(area_id)] = _create_area(area_id,
+                                                                       area_content)
+            except KeyError:
+                raise ValueError('Invalid area definition: %s, %s' % (area_id, area_content))
         else:
             area_content += line
 
@@ -298,6 +305,110 @@ def get_area_def(area_id, area_name, proj_id, proj4_args, x_size, y_size,
                           x_size, y_size, area_extent)
 
 
+def _get_area_def_from_gdal(dataset, area_id=None, name=None, proj_id=None, proj_dict=None):
+    from pyresample.geometry import AreaDefinition
+
+    # a: width of a pixel
+    # b: row rotation (typically zero)
+    # c: x-coordinate of the upper-left corner of the upper-left pixel
+    # d: column rotation (typically zero)
+    # e: height of a pixel (typically negative)
+    # f: y-coordinate of the of the upper-left corner of the upper-left pixel
+    c, a, b, f, d, e = dataset.GetGeoTransform()
+    if not (b == d == 0):
+        raise ValueError('Rotated rasters are not supported at this time.')
+    area_extent = (c, f + e * dataset.RasterYSize, c + a * dataset.RasterXSize, f)
+
+    if proj_dict is None:
+        from osgeo import osr
+        proj = dataset.GetProjection()
+        if proj != '':
+            sref = osr.SpatialReference(wkt=proj)
+            proj_dict = proj4_str_to_dict(sref.ExportToProj4())
+        else:
+            raise ValueError('The source raster is not gereferenced, please provide the value of proj_dict')
+
+        if proj_id is None:
+            proj_id = proj.split('"')[1]
+
+    area_def = AreaDefinition(area_id, name, proj_id, proj_dict,
+                              dataset.RasterXSize, dataset.RasterYSize, area_extent)
+    return area_def
+
+
+def _get_area_def_from_rasterio(dataset, area_id, name, proj_id=None, proj_dict=None):
+    from pyresample.geometry import AreaDefinition
+
+    a, b, c, d, e, f, _, _, _ = dataset.transform
+    if not (b == d == 0):
+        raise ValueError('Rotated rasters are not supported at this time.')
+
+    if proj_dict is None:
+        crs = dataset.crs
+        if crs is not None:
+            proj_dict = dataset.crs.to_dict()
+        else:
+            raise ValueError('The source raster is not gereferenced, please provide the value of proj_dict')
+
+        if proj_id is None:
+            proj_id = crs.wkt.split('"')[1]
+
+    area_def = AreaDefinition(area_id, name, proj_id, proj_dict,
+                              dataset.width, dataset.height, dataset.bounds)
+    return area_def
+
+
+def get_area_def_from_raster(source, area_id=None, name=None, proj_id=None, proj_dict=None):
+    """Construct AreaDefinition object from raster
+
+    Parameters
+    ----------
+    source : str, Dataset, DatasetReader or DatasetWriter
+        A file name. Also it can be ``osgeo.gdal.Dataset``,
+        ``rasterio.io.DatasetReader`` or ``rasterio.io.DatasetWriter``
+    area_id : str, optional
+        ID of area
+    name : str, optional
+        Name of area
+    proj_id : str, optional
+        ID of projection
+    proj_dict : dict, optional
+        PROJ.4 parameters
+
+    Returns
+    -------
+    area_def : object
+        AreaDefinition object
+    """
+    try:
+        import rasterio
+    except ImportError:
+        rasterio = None
+        try:
+            from osgeo import gdal
+        except ImportError:
+            raise ImportError('Either rasterio or gdal must be available')
+
+    cleanup_gdal = cleanup_rasterio = None
+    if isinstance(source, (str, six.text_type)):
+        if rasterio is not None:
+            source = rasterio.open(source)
+            cleanup_rasterio = True
+        else:
+            source = gdal.Open(source)
+            cleanup_gdal = True
+
+    try:
+        if rasterio is not None and isinstance(source, (rasterio.io.DatasetReader, rasterio.io.DatasetWriter)):
+            return _get_area_def_from_rasterio(source, area_id, name, proj_id, proj_dict)
+        return _get_area_def_from_gdal(source, area_id, name, proj_id, proj_dict)
+    finally:
+        if cleanup_rasterio:
+            source.close()
+        elif cleanup_gdal:
+            source = None
+
+
 def generate_quick_linesample_arrays(source_area_def, target_area_def,
                                      nprocs=1):
     """Generate linesample arrays for quick grid resampling
@@ -408,15 +519,31 @@ def fwhm2sigma(fwhm):
     return fwhm / (2 * np.sqrt(np.log(2)))
 
 
+def convert_proj_floats(proj_pairs):
+    """Convert PROJ.4 parameters to floats if possible."""
+    proj_dict = OrderedDict()
+    for x in proj_pairs:
+        if len(x) == 1 or x[1] is True:
+            proj_dict[x[0]] = True
+            continue
+
+        try:
+            proj_dict[x[0]] = float(x[1])
+        except ValueError:
+            proj_dict[x[0]] = x[1]
+
+    return proj_dict
+
+
 def _get_proj4_args(proj4_args):
     """Create dict from proj4 args
     """
 
     if isinstance(proj4_args, (str, six.text_type)):
-        proj_config = ConfigObj(str(proj4_args).replace('+', '').split())
+        proj_config = proj4_str_to_dict(str(proj4_args))
     else:
         proj_config = ConfigObj(proj4_args)
-    return proj_config.dict()
+    return convert_proj_floats(proj_config.items())
 
 
 def proj4_str_to_dict(proj4_str):
@@ -425,7 +552,7 @@ def proj4_str_to_dict(proj4_str):
     Note: Key only parameters will be assigned a value of `True`.
     """
     pairs = (x.split('=', 1) for x in proj4_str.replace('+', '').split(" "))
-    return dict((x[0], (x[1] if len(x) == 2 else True)) for x in pairs)
+    return convert_proj_floats(pairs)
 
 
 def proj4_dict_to_str(proj4_dict, sort=False):
@@ -554,3 +681,14 @@ def recursive_dict_update(d, u):
         else:
             d[k] = u[k]
     return d
+
+
+def convert_def_to_yaml(def_area_file, yaml_area_file):
+    """Convert a legacy area def file to the yaml counter partself.
+
+    *yaml_area_file* will be overwritten by the operation.
+    """
+    areas = _parse_legacy_area_file(def_area_file)
+    with open(yaml_area_file, 'w') as yaml_file:
+        for area in areas:
+            yaml_file.write(area.create_areas_def())
